<p align="center">
    <a href="https://django-glue.stratusadv.com">
        <img alt="Django Glue Logo" src="https://django-glue.stratusadv.com/static/img/django_glue_logo_256.png"/>
    </a>
</p>

# Django Glue

![Build](https://img.shields.io/github/actions/workflow/status/stratusadv/django-glue/run_tests.yml)
![Python Versions](https://img.shields.io/pypi/pyversions/django-glue)
![PyPI Version](https://img.shields.io/pypi/v/django-glue)
![Downloads](https://img.shields.io/pypi/dm/django-glue)

### Seamlessly Connect Django to your Frontend.

## Features

- **Powerful, Declarative API** 
  - Powerful API that makes it dead simple to interact with Django server state from
    JavaScript in a way that feels like you never left your Django view.
- **Unintrusive Integration** 
  - Stays out of your way and works with your existing application with no need to rewrite
    your Django views or frontend code.
- **Frontend Framework Agnostic** 
  - Designed to work with any style of frontend development with no additional JavaScript
    dependencies or bloat.
- **Naturally Pythonic** 
  - Written by Python developers, for Python developers. It adheres to pythonic syntax and philosophies
    everywhere, even in JavaScript.
- **Granular Access Control** 
  - Designed with security at top of mind, with the ability to precisely control backend data
    access.
- **Extensible & Easy** 
  - Can be extended to support any custom object and action needed for your use case at any point in your
    project.


## Documentation

Check out the [Django Glue Website](https://django-glue.stratusadv.com) for documentation including tutorials and more.

